<?php

/*
   Plugin Name: Acumbamail
   Plugin URI: https://acumbamail.com/integraciones/wordpress
   Description: Plugin para Wordpress destinado a la integración de los formularios de Acumbamail
   Version: 2.0.0
   Author: Acumbamail
   Author URI: https://acumbamail.com
   License: GPLv3
   License URI: https://www.gnu.org/licenses/gpl.html
*/

defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

require('api/acumbamail.class.php');
require('acumbamail_widget.php');

add_action('admin_menu', 'acumbamail_configuration');
add_action('admin_init', 'acumbamail_admin_init');
add_action( 'widgets_init', 'register_acumbamail_widget' );

if (in_array('woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins')))) {
    add_action('woocommerce_order_status_processing', 'acumbamail_woocommerce_subscribe_client');
}

function register_acumbamail_widget() {
    register_widget('Acumbamail_Widget');
}

function acumbamail_configuration() {
    add_menu_page(
        __('Gestiona tus suscripciones en Acumbamail'),
        'Acumbamail',
        'manage_options',
        'acumbamail',
        'acumbamail_options_page',
        plugin_dir_url(dirname(__FILE__) . '/acumbamail.php').'img/logo.png'
    );
    
    if (in_array('woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins')))) {
        add_submenu_page('acumbamail',
                         __('Configura el formulario para mostrarlo en tus páginas de Wordpress'),
                         'Woocommerce',
                         'manage_options',
                         'acumbamail_woocommerce',
                         'acumbamail_woocommerce_options_page');
    }
}

function acumbamail_options_page() {
    $acumbamail_settings_section = 'acumbamail';
    require('inc/admin_page.php');
}

function acumbamail_woocommerce_options_page() {
    $acumbamail_settings_section = 'acumbamail_woocommerce';
    require('inc/admin_page.php');
}

function acumbamail_register_settings_section($api) {
    $options = get_option('acumbamail_options');
    add_settings_section('acumbamail_main', __('Integre sus formularios de Acumbamail en sus páginas de Wordpress'), 'acumbamail_options_text', 'acumbamail');
    acumbamail_show_auth_token_textbox('acumbamail', 'acumbamail_main');
    
    if ($api->getLists()) {
        $additional_args['field_name'] = 'list_id';
        add_settings_field('acumbamail_list_id', 'Lista: ', 'acumbamail_list_id_field', 'acumbamail', 'acumbamail_main', $additional_args);
    }
    
    if (isset($options['list_id']) and $options['list_id'] != -1 and $api->getForms($options['list_id'])) {
        add_settings_field('acumbamail_form_id', 'Formulario: ', 'acumbamail_form_id_field', 'acumbamail', 'acumbamail_main');
    }
}

function acumbamail_register_woocommerce_settings_section($api) {
    add_settings_section('acumbamail_woocommerce', __('Configure aquí la lista de Acumbamail a la que se suscribirán automáticamente sus compradores'),
                         'acumbamail_options_text', 'acumbamail_woocommerce');
    
    acumbamail_show_auth_token_textbox('acumbamail_woocommerce', 'acumbamail_woocommerce');
    
    if ($api->getLists()) {
        $additional_args['field_name'] = 'woocommerce_list_id';
        add_settings_field('acumbamail_woocommerce_list_id', 'Lista: ', 'acumbamail_list_id_field', 'acumbamail_woocommerce',
                           'acumbamail_woocommerce', $additional_args);
    }
}

function acumbamail_show_auth_token_textbox($page, $section) {
    add_settings_field('acumbamail_auth_token', 'Auth Token: ', 'acumbamail_auth_token_field', $page, $section);
}

function acumbamail_admin_init() {
    $options = get_option('acumbamail_options');
    $api = new AcumbamailAPI('', $options['auth_token']);
    
    register_setting('acumbamail_options', 'acumbamail_options', 'acumbamail_options_validate');
    acumbamail_register_settings_section($api);
    acumbamail_register_woocommerce_settings_section($api);
}

function compose_options_for_select_html_field($options, $selected_value) {
    foreach ($options as $key => $value) {
        $selected = '';
        if ($selected_value == $key) {
            $selected = 'selected';
        }
        echo "<option value=" . $key . " " . $selected . ">" . $value['name'] . "</option>";
    }
}

function acumbamail_get_form_details() {
    $options = get_option('acumbamail_options');
    $api = new AcumbamailAPI('', $options['auth_token']);
    $form_details = $api->getFormDetails($options['form_id']);
    
    return $form_details;
}

function acumbamail_options_validate($input) {
    if (isset($_POST['reset'])) {
        $output = var_export($_POST, true);
        return array();
    }
    
    $options = get_option('acumbamail_options');
    foreach ($input as $key => $value) {
        $options[$key] = $value;
    }
    return $options;
}

function acumbamail_auth_token_field() {
    $options = get_option('acumbamail_options');
    echo "<input id='acumbamail_auth_token' name='acumbamail_options[auth_token]' size=20 type='text' value='{$options['auth_token']}'>";
}

function acumbamail_list_id_field($additional_args) {
    $options = get_option('acumbamail_options');
    $api = new AcumbamailAPI('', $options['auth_token']);
    $lists = $api->getLists();
    echo "<select id='acumbamail_'" . $additional_args['field_name'] . " name='acumbamail_options[" . $additional_args['field_name'] . "]'>";
    echo "<option value=-1>-- " . __("Seleccione Lista") . "--</option>";
    compose_options_for_select_html_field($lists, $options[$additional_args['field_name']]);
    echo '</select>';
}

function acumbamail_form_id_field() {
    $options = get_option('acumbamail_options');
    $api = new AcumbamailAPI('', $options['auth_token']);
    $forms = $api->getForms($options['list_id']);
    echo "<select id='acumbamail_form_id' name='acumbamail_options[form_id]'>";
    echo "<option value=-1>-- " . __("Seleccione Formulario") . "--</option>";
    compose_options_for_select_html_field($forms, $options['form_id']);
    echo "</select>";
}

function acumbamail_options_text() {
}

function acumbamail_woocommerce_subscribe_client($order_id) {
    // Retrieving email from order object
    $order = new WC_Order($order_id);
    $subscriber_fields = array();
    $subscriber_fields['email'] = $order->billing_email;
    $options = get_option('acumbamail_options');
    $api = new AcumbamailAPI('', $options['auth_token']);
    $api->addSubscriber($options['woocommerce_list_id'], $subscriber_fields);
}
